Documentation
¶
Overview ¶
Package cache provides type definitions for use with the Chrome ApplicationCache protocol
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationCache ¶
type ApplicationCache struct {
// Manifest URL.
ManifestURL string `json:"manifestURL"`
// Application cache size.
Size float64 `json:"size"`
// Application cache creation time.
CreationTime float64 `json:"creationTime"`
// Application cache update time.
UpdateTime float64 `json:"updateTime"`
// Application cache resources.
Resources []*Resource `json:"resources"`
}
ApplicationCache contains detailed application cache information.
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#type-ApplicationCache
type EnableResult ¶
type EnableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
EnableResult represents the result of calls to ApplicationCache.enable.
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#method-enable
type FrameWithManifest ¶
type FrameWithManifest struct {
// Frame identifier.
FrameID page.FrameID `json:"frameId"`
// Manifest URL.
ManifestURL string `json:"manifestURL"`
// Application cache status.
Status int `json:"status"`
}
FrameWithManifest is a frame identifier / manifest URL pair.
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#type-FrameWithManifest
type GetForFrameParams ¶
type GetForFrameParams struct {
// Identifier of the frame containing document whose application cache is
// retrieved.
FrameID page.FrameID `json:"frameId"`
}
GetForFrameParams represents ApplicationCache.getApplicationCacheForFrame parameters
type GetForFrameResult ¶
type GetForFrameResult struct {
// Relevant application cache data for the document in given frame.
ApplicationCache *ApplicationCache `json:"applicationCache"`
// Error information related to executing this method
Err error `json:"-"`
}
GetForFrameResult represents the result of calls to ApplicationCache.getApplicationCacheForFrame.
type GetFramesWithManifestsResult ¶
type GetFramesWithManifestsResult struct {
// Array of frame identifiers with manifest urls for each frame containing a
// document associated with some application cache.
FrameIDs []*FrameWithManifest `json:"frameIds"`
// Error information related to executing this method
Err error `json:"-"`
}
GetFramesWithManifestsResult represents the result of calls to ApplicationCache.getFramesWithManifests.
type GetManifestForFrameParams ¶
type GetManifestForFrameParams struct {
// Identifier of the frame containing document whose manifest is retrieved.
FrameID page.FrameID `json:"frameId"`
}
GetManifestForFrameParams represents ApplicationCache.getFramesWithManifests parameters
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#method-getManifestForFrame
type GetManifestForFrameResult ¶
type GetManifestForFrameResult struct {
// Manifest URL for document in the given frame.
ManifestURL string `json:"manifestURL"`
// Error information related to executing this method
Err error `json:"-"`
}
GetManifestForFrameResult represents the result of calls to ApplicationCache.getManifestForFrame.
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#method-getManifestForFrame
type NetworkStateUpdatedEvent ¶
type NetworkStateUpdatedEvent struct {
IsNowOnline bool `json:"isNowOnline"`
// Error information related to this event
Err error `json:"-"`
}
NetworkStateUpdatedEvent represents ApplicationCache.applicationCachenetworkStateUpdated event data.
https://chromedevtools.github.io/devtools-protocol/tot/ApplicationCache/#event-networkStateUpdated
type Resource ¶
type Resource struct {
// Resource URL.
URL string `json:"url"`
// Resource size.
Size int `json:"size"`
// Resource type.
Type string `json:"type"`
}
Resource contains detailed application cache resource information.
type StatusUpdatedEvent ¶
type StatusUpdatedEvent struct {
// Identifier of the frame containing document whose application cache
// updated status.
FrameID page.FrameID `json:"frameId"`
// Manifest URL.
ManifestURL string `json:"manifestURL"`
// Updated application cache status.
Status int `json:"status"`
// Error information related to this event
Err error `json:"-"`
}
StatusUpdatedEvent represents ApplicationCache.applicationCacheStatusUpdated event data.