Documentation
¶
Overview ¶
Package console provides type definitions for use with the Chrome Console protocol
https://chromedevtools.github.io/devtools-protocol/tot/Console/
Package console provides type definitions for use with the Chrome Console protocol ¶
https://chromedevtools.github.io/devtools-protocol/tot/Console/
Index ¶
Constants ¶
This section is empty.
Variables ¶
var MessageLevel = messageLevelEnum{ Log: MessageLevelLog, Warning: MessageLevelWarning, Error: MessageLevelError, Debug: MessageLevelDebug, Info: MessageLevelInfo, }
MessageLevel provides named acces to the MessageLevelEnum values.
var MessageSource = messageSourceEnum{ XML: MessageSourceXML, Javascript: MessageSourceJavascript, Network: MessageSourceNetwork, ConsoleAPI: MessageSourceConsoleAPI, Storage: MessageSourceStorage, Appcache: MessageSourceAppcache, Rendering: MessageSourceRendering, Security: MessageSourceSecurity, Other: MessageSourceOther, Deprecation: MessageSourceDeprecation, Worker: MessageSourceWorker, }
MessageSource provides named acces to the MessageSourceEnum values.
Functions ¶
This section is empty.
Types ¶
type ClearMessagesResult ¶
type ClearMessagesResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
ClearMessagesResult represents the result of calls to Console.ClearMessages.
https://chromedevtools.github.io/devtools-protocol/tot/Console/#method-clearMessages
type DisableResult ¶
type DisableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
DisableResult represents the result of calls to Console.disable.
https://chromedevtools.github.io/devtools-protocol/tot/Console/#method-disable
type EnableResult ¶
type EnableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
EnableResult represents the result of calls to Console.enable.
https://chromedevtools.github.io/devtools-protocol/tot/Console/#method-enable
type Message ¶
type Message struct {
// Message source. Allowed values:
// - MessageSource.XML - "xml"
// - MessageSource.Javascript - "javascript"
// - MessageSource.Network - "network"
// - MessageSource.ConsoleAPI - "console-api"
// - MessageSource.Storage - "storage"
// - MessageSource.Appcache - "appcache"
// - MessageSource.Rendering - "rendering"
// - MessageSource.Security - "security"
// - MessageSource.Other - "other"
// - MessageSource.Deprecation - "deprecation"
// - MessageSource.Worker - "worker"
Source MessageSourceEnum `json:"source"`
// Message severity. Allowed values:
// - MessageLevel.Log - "log"
// - MessageLevel.Warning - "warning"
// - MessageLevel.Error - "error"
// - MessageLevel.Debug - "debug"
// - MessageLevel.Info - "info"
Level MessageLevelEnum `json:"level"`
// Message text.
Text string `json:"text"`
// Optional. URL of the message origin.
URL string `json:"url,omitempty"`
// Optional. Line number in the resource that generated this message
// (1-based).
Line int `json:"line,omitempty"`
// Optional. Column number in the resource that generated this message
// (1-based).
Column int `json:"column,omitempty"`
}
Message represents a console message.
https://chromedevtools.github.io/devtools-protocol/tot/Console/#type-ConsoleMessage
type MessageAddedEvent ¶
type MessageAddedEvent struct {
// Console message that has been added.
Message *Message `json:"message"`
// Error information related to this event
Err error `json:"-"`
}
MessageAddedEvent represents Console.messageAdded event data.
https://chromedevtools.github.io/devtools-protocol/tot/Console/#event-messageAdded
type MessageLevelEnum ¶
type MessageLevelEnum int
MessageLevelEnum represents the message severity. Allowed values:
- MessageLevel.Log "log"
- MessageLevel.Warning "warning"
- MessageLevel.Error "error"
- MessageLevel.Debug "debug"
- MessageLevel.Info "info"
https://chromedevtools.github.io/devtools-protocol/tot/Console/#type-ConsoleMessage
const ( // MessageLevelLog represents the "log" value. MessageLevelLog MessageLevelEnum = iota + 1 // MessageLevelWarning represents the "warning" value. MessageLevelWarning // MessageLevelError represents the "error" value. MessageLevelError // MessageLevelDebug represents the "debug" value. MessageLevelDebug // MessageLevelInfo represents the "info" value. MessageLevelInfo )
func (MessageLevelEnum) MarshalJSON ¶
func (enum MessageLevelEnum) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (MessageLevelEnum) String ¶
func (enum MessageLevelEnum) String() string
String implements Stringer
func (*MessageLevelEnum) UnmarshalJSON ¶
func (enum *MessageLevelEnum) UnmarshalJSON(bytes []byte) error
UnmarshalJSON implements json.Unmarshaler
type MessageSourceEnum ¶
type MessageSourceEnum int
MessageSourceEnum represents the message source. Allowed values:
- MessageSource.XML "xml"
- MessageSource.Javascript "javascript"
- MessageSource.Network "network"
- MessageSource.ConsoleAPI "console-api"
- MessageSource.Storage "storage"
- MessageSource.Appcache "appcache"
- MessageSource.Rendering "rendering"
- MessageSource.Security "security"
- MessageSource.Other "other"
- MessageSource.Deprecation "deprecation"
- MessageSource.Worker "worker"
const ( // MessageSourceXML represents the "xml" value MessageSourceXML MessageSourceEnum = iota + 1 // MessageSourceJavascript represents the "javascript" value MessageSourceJavascript // MessageSourceNetwork represents the "network" value MessageSourceNetwork // MessageSourceConsoleAPI represents the "console-api" value MessageSourceConsoleAPI // MessageSourceStorage represents the "storage" value MessageSourceStorage // MessageSourceAppcache represents the "appcache" value MessageSourceAppcache // MessageSourceRendering represents the "rendering" value MessageSourceRendering // MessageSourceSecurity represents the "security" value MessageSourceSecurity // MessageSourceOther represents the "other" value MessageSourceOther // MessageSourceDeprecation represents the "deprecation" value MessageSourceDeprecation // MessageSourceWorker represents the "worker" value MessageSourceWorker )
func (MessageSourceEnum) MarshalJSON ¶
func (enum MessageSourceEnum) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (MessageSourceEnum) String ¶
func (enum MessageSourceEnum) String() string
String implements Stringer
func (*MessageSourceEnum) UnmarshalJSON ¶
func (enum *MessageSourceEnum) UnmarshalJSON(bytes []byte) error
UnmarshalJSON implements json.Unmarshaler