Documentation
¶
Overview ¶
Package database provides type definitions for use with the Chrome Database protocol
https://chromedevtools.github.io/devtools-protocol/tot/Database/
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddEvent ¶
type AddEvent struct {
// Database object.
Database *Database
// Error information related to this event
Err error `json:"-"`
}
AddEvent represents Database.addDatabase event data.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#event-addDatabase
type Database ¶
type Database struct {
// Database ID.
ID ID `json:"id"`
// Database domain.
Domain string `json:"domain"`
// Database name.
Name string `json:"name"`
// Database version.
Version string `json:"version"`
}
Database is a database object
https://chromedevtools.github.io/devtools-protocol/tot/Database/#type-Database
type DisableResult ¶
type DisableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
DisableResult represents the result of calls to Database.disable.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-disable
type EnableResult ¶
type EnableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
EnableResult represents the result of calls to Database.enable.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-enable
type Error ¶
type Error struct {
// Error code.
Code int `json:"code"`
// Error message.
Message string `json:"message"`
}
Error is a database error.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#type-Error
type ExecuteSQLParams ¶
ExecuteSQLParams represents Database.executeSQL parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-executeSQL
type ExecuteSQLResult ¶
type ExecuteSQLResult struct {
// Column names.
ColumnNames []string `json:"columnNames"`
// Values.
Values []interface{} `json:"values"`
// Optional. Error, if any.
SQLError *Error `json:"sqlError,omitempty"`
// Error information related to executing this method
Err error `json:"-"`
}
ExecuteSQLResult represents the result of calls to Database.executeSQL.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-executeSQL
type GetTableNamesParams ¶
type GetTableNamesParams struct {
ID ID `json:"databaseId"`
}
GetTableNamesParams represents Database.getDatabaseTableNames parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-getDatabaseTableNames
type GetTableNamesResult ¶
type GetTableNamesResult struct {
// Table names.
TableNames []string `json:"tableNames"`
// Error information related to executing this method
Err error `json:"-"`
}
GetTableNamesResult represents the result of calls to Database.getDatabaseTableNames.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#method-getDatabaseTableNames
type ID ¶
type ID string
ID is a unique identifier of a database object.
https://chromedevtools.github.io/devtools-protocol/tot/Database/#type-DatabaseId