Documentation
¶
Overview ¶
Package profiler provides type definitions for use with the Chrome HeapProfiler protocol
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/
Index ¶
- type AddHeapSnapshotChunkEvent
- type AddInspectedHeapObjectParams
- type AddInspectedHeapObjectResult
- type CollectGarbageResult
- type DisableResult
- type EnableResult
- type GetHeapObjectIDParams
- type GetHeapObjectIDResult
- type GetObjectByHeapObjectIDParams
- type GetObjectByHeapObjectIDResult
- type GetSamplingProfileParams
- type GetSamplingProfileResult
- type HeapSnapshotObjectID
- type HeapStatsUpdateEvent
- type LastSeenObjectIDEvent
- type ReportHeapSnapshotProgressEvent
- type ResetProfilesEvent
- type SamplingHeapProfile
- type SamplingHeapProfileNode
- type StartSamplingParams
- type StartSamplingResult
- type StartTrackingHeapObjectsParams
- type StartTrackingHeapObjectsResult
- type StopSamplingParams
- type StopSamplingResult
- type StopTrackingHeapObjectsParams
- type StopTrackingHeapObjectsResult
- type TakeHeapSnapshotParams
- type TakeHeapSnapshotResult
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddHeapSnapshotChunkEvent ¶
type AddHeapSnapshotChunkEvent struct {
Chunk string `json:"chunk"`
// Error information related to this event
Err error `json:"-"`
}
AddHeapSnapshotChunkEvent represents DOM.addHeapSnapshotChunk event data.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#event-addHeapSnapshotChunk
type AddInspectedHeapObjectParams ¶
type AddInspectedHeapObjectParams struct {
// Heap snapshot object ID to be accessible by means of $x command line API.
HeapObjectID HeapSnapshotObjectID `json:"heapObjectId"`
}
AddInspectedHeapObjectParams represents HeapProfiler.addInspectedHeapObject parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-addInspectedHeapObject
type AddInspectedHeapObjectResult ¶
type AddInspectedHeapObjectResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
AddInspectedHeapObjectResult represents the result of calls to HeapProfiler.AddInspectedHeapObject.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-addInspectedHeapObject
type CollectGarbageResult ¶
type CollectGarbageResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
CollectGarbageResult represents the result of calls to HeapProfiler.collectGarbage.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-collectGarbage
type DisableResult ¶
type DisableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
DisableResult represents the result of calls to HeapProfiler.disable.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-disable
type EnableResult ¶
type EnableResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
EnableResult represents the result of calls to HeapProfiler.enable.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-enable
type GetHeapObjectIDParams ¶
type GetHeapObjectIDParams struct {
// Identifier of the object to get heap object ID for.
ObjectID runtime.RemoteObjectID `json:"objectId"`
}
GetHeapObjectIDParams represents HeapProfiler.getHeapObjectId parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getHeapObjectId
type GetHeapObjectIDResult ¶
type GetHeapObjectIDResult struct {
// ID of the heap snapshot object corresponding to the passed remote object
// id.
HeapSnapshotObjectID HeapSnapshotObjectID `json:"heapSnapshotObjectId"`
// Error information related to executing this method
Err error `json:"-"`
}
GetHeapObjectIDResult represents the result of calls to HeapProfiler.getHeapObjectId.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getHeapObjectId
type GetObjectByHeapObjectIDParams ¶
type GetObjectByHeapObjectIDParams struct {
// desc.
ObjectID HeapSnapshotObjectID `json:"objectId"`
// Optional. Symbolic group name that can be used to release multiple
// objects.
ObjectGroup string `json:"objectGroup,omitempty"`
}
GetObjectByHeapObjectIDParams represents HeapProfiler.getObjectByHeapObjectId parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getObjectByHeapObjectId
type GetObjectByHeapObjectIDResult ¶
type GetObjectByHeapObjectIDResult struct {
// Evaluation result.
Result *runtime.RemoteObject `json:"result"`
// Error information related to executing this method
Err error `json:"-"`
}
GetObjectByHeapObjectIDResult represents the result of calls to HeapProfiler.getObjectByHeapObjectId.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getObjectByHeapObjectId
type GetSamplingProfileParams ¶
type GetSamplingProfileParams struct {
// Return the sampling profile being collected.
Profile *SamplingHeapProfile `json:"profile"`
}
GetSamplingProfileParams represents HeapProfiler.getSamplingProfile parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getSamplingProfile
type GetSamplingProfileResult ¶
type GetSamplingProfileResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
GetSamplingProfileResult represents the result of calls to HeapProfiler.getSamplingProfile.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-getSamplingProfile
type HeapSnapshotObjectID ¶
type HeapSnapshotObjectID string
HeapSnapshotObjectID is the heap snapshot object id.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#type-HeapSnapshotObjectId
type HeapStatsUpdateEvent ¶
type HeapStatsUpdateEvent struct {
// An array of triplets. Each triplet describes a fragment. The first
// integer is the fragment index, the second integer is a total count of
// objects for the fragment, the third integer is a total size of the
// objects for the fragment.
StatsUpdate []int `json:"statsUpdate"`
// Error information related to this event
Err error `json:"-"`
}
HeapStatsUpdateEvent represents DOM.heapStatsUpdate event data.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#event-heapStatsUpdate
type LastSeenObjectIDEvent ¶
type LastSeenObjectIDEvent struct {
//
LastSeenObjectID int `json:"lastSeenObjectId"`
//
Timestamp int `json:"timestamp"`
// Error information related to this event
Err error `json:"-"`
}
LastSeenObjectIDEvent represents DOM.lastSeenObjectId event data.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#event-lastSeenObjectId
type ReportHeapSnapshotProgressEvent ¶
type ReportHeapSnapshotProgressEvent struct {
//
Done int `json:"done"`
//
Total int `json:"total"`
// Optional.
Finished bool `json:"finished,omitempty"`
// Error information related to this event
Err error `json:"-"`
}
ReportHeapSnapshotProgressEvent represents DOM.reportHeapSnapshotProgress event data.
type ResetProfilesEvent ¶
type ResetProfilesEvent struct {
// Error information related to this event
Err error `json:"-"`
}
ResetProfilesEvent represents DOM.resetProfiles event data.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#event-resetProfiles
type SamplingHeapProfile ¶
type SamplingHeapProfile struct {
Head *SamplingHeapProfileNode `json:"head"`
}
SamplingHeapProfile represents a heap sample profile
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#type-SamplingHeapProfile
type SamplingHeapProfileNode ¶
type SamplingHeapProfileNode struct {
// Function location.
CallFrame *runtime.CallFrame `json:"callFrame"`
// Allocations size in bytes for the node excluding children.
SelfSize int `json:"selfSize"`
// Child nodes.
Children []*SamplingHeapProfileNode `json:"children"`
}
SamplingHeapProfileNode is the sampling Heap Profile node. Holds callsite information, allocation statistics and child nodes.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#type-SamplingHeapProfileNode
type StartSamplingParams ¶
type StartSamplingParams struct {
// Optional. Average sample interval in bytes. Poisson distribution is used
// for the intervals. The default value is 32768 bytes.
SamplingInterval int `json:"samplingInterval,omitempty"`
}
StartSamplingParams represents HeapProfiler.startSampling parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-startSampling
type StartSamplingResult ¶
type StartSamplingResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
StartSamplingResult represents the result of calls to HeapProfiler.startSampling.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-startSampling
type StartTrackingHeapObjectsParams ¶
type StartTrackingHeapObjectsParams struct {
// Optional.
TrackAllocations bool `json:"trackAllocations,omitempty"`
}
StartTrackingHeapObjectsParams represents HeapProfiler.startTrackingHeapObjects parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-startTrackingHeapObjects
type StartTrackingHeapObjectsResult ¶
type StartTrackingHeapObjectsResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
StartTrackingHeapObjectsResult represents the result of calls to HeapProfiler.startTrackingHeapObjects.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-startTrackingHeapObjects
type StopSamplingParams ¶
type StopSamplingParams struct {
// Recorded sampling heap profile.
Profile *SamplingHeapProfile `json:"profile"`
}
StopSamplingParams represents HeapProfiler.stopSampling parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-stopSampling
type StopSamplingResult ¶
type StopSamplingResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
StopSamplingResult represents the result of calls to HeapProfiler.stopSampling.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-stopSampling
type StopTrackingHeapObjectsParams ¶
type StopTrackingHeapObjectsParams struct {
// Optional. If true 'reportHeapSnapshotProgress' events will be generated
// while snapshot is being taken when the tracking is stopped.
ReportProgress bool `json:"reportProgress,omitempty"`
}
StopTrackingHeapObjectsParams represents HeapProfiler.stopTrackingHeapObjects parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-stopTrackingHeapObjects
type StopTrackingHeapObjectsResult ¶
type StopTrackingHeapObjectsResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
StopTrackingHeapObjectsResult represents the result of calls to HeapProfiler.stopTrackingHeapObjects.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-stopTrackingHeapObjects
type TakeHeapSnapshotParams ¶
type TakeHeapSnapshotParams struct {
// Optional. If true 'reportHeapSnapshotProgress' events will be generated
// while snapshot is being taken.
ReportProgress bool `json:"reportProgress,omitempty"`
}
TakeHeapSnapshotParams represents HeapProfiler.takeHeapSnapshot parameters.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-takeHeapSnapshot
type TakeHeapSnapshotResult ¶
type TakeHeapSnapshotResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
TakeHeapSnapshotResult represents the result of calls to HeapProfiler.takeHeapSnapshot.
https://chromedevtools.github.io/devtools-protocol/tot/HeapProfiler/#method-takeHeapSnapshot