Documentation
¶
Overview ¶
Package target provides type definitions for use with the Chrome Target protocol
https://chromedevtools.github.io/devtools-protocol/tot/Target/
Index ¶
- type ActivateTargetParams
- type ActivateTargetResult
- type AttachToTargetParams
- type AttachToTargetResult
- type AttachedToTargetEvent
- type BrowserContextID
- type CloseTargetParams
- type CloseTargetResult
- type CreateBrowserContextResult
- type CreateTargetParams
- type CreateTargetResult
- type CreatedEvent
- type DestroyedEvent
- type DetachFromTargetParams
- type DetachFromTargetResult
- type DetachedFromTargetEvent
- type DisposeBrowserContextParams
- type DisposeBrowserContextResult
- type GetTargetInfoParams
- type GetTargetInfoResult
- type GetTargetsParams
- type GetTargetsResult
- type ID
- type Info
- type InfoChangedEvent
- type ReceivedMessageFromTargetEvent
- type RemoteLocation
- type SendMessageToTargetParams
- type SendMessageToTargetResult
- type SessionID
- type SetAttachToFramesParams
- type SetAttachToFramesResult
- type SetAutoAttachParams
- type SetAutoAttachResult
- type SetDiscoverTargetsParams
- type SetDiscoverTargetsResult
- type SetRemoteLocationsParams
- type SetRemoteLocationsResult
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActivateTargetParams ¶
type ActivateTargetParams struct {
// Target ID.
ID ID `json:"targetId"`
}
ActivateTargetParams represents Target.activateTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-activateTarget
type ActivateTargetResult ¶
type ActivateTargetResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
ActivateTargetResult represents the result of calls to Target.activateTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-activateTarget
type AttachToTargetParams ¶
type AttachToTargetParams struct {
// Target ID.
ID ID `json:"targetId"`
}
AttachToTargetParams represents Target.attachToTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-attachToTarget
type AttachToTargetResult ¶
type AttachToTargetResult struct {
// Id assigned to the session.
SessionID SessionID `json:"sessionId"`
// Error information related to executing this method
Err error `json:"-"`
}
AttachToTargetResult represents the result of calls to Target.attachToTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-attachToTarget
type AttachedToTargetEvent ¶
type AttachedToTargetEvent struct {
// Identifier assigned to the session used to send/receive messages.
SessionID SessionID `json:"sessionId"`
// Target info.
Info *Info `json:"targetInfo"`
// Waiting for debugger.
WaitingForDebugger bool `json:"waitingForDebugger"`
// Error information related to this event
Err error `json:"-"`
}
AttachedToTargetEvent represents Target.attachedToTarget event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-attachedToTarget
type BrowserContextID ¶
type BrowserContextID string
BrowserContextID is EXPERIMENTAL
https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-BrowserContextID
type CloseTargetParams ¶
type CloseTargetParams struct {
// Target ID.
ID ID `json:"targetId"`
}
CloseTargetParams represents Target.closeTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-closeTarget
type CloseTargetResult ¶
type CloseTargetResult struct {
// Target close status
Success bool `json:"success"`
// Error information related to executing this method
Err error `json:"-"`
}
CloseTargetResult represents the result of calls to Target.closeTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-closeTarget
type CreateBrowserContextResult ¶
type CreateBrowserContextResult struct {
// The ID of the context created.
BrowserContextID BrowserContextID `json:"browserContextId"`
// Error information related to executing this method
Err error `json:"-"`
}
CreateBrowserContextResult represents the result of calls to Target.createBrowserContext.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-createBrowserContext
type CreateTargetParams ¶
type CreateTargetParams struct {
// The initial URL the page will be navigated to.
URL string `json:"url"`
// Optional. Frame width in DIP (headless chrome only).
Width int `json:"width,omitempty"`
// Optional. Frame height in DIP (headless chrome only).
Height int `json:"height,omitempty"`
// Optional. The browser context to create the page in (headless chrome only).
BrowserContextID BrowserContextID `json:"browserContextId,omitempty"`
// Optional. Whether BeginFrames for this target will be controlled via
// DevTools (headless chrome only, not supported on MacOS yet, false by
// default). EXPERIMENTAL.
EnableBeginFrameControl bool `json:"enableBeginFrameControl,omitempty"`
}
CreateTargetParams represents Target.createTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-createTarget
type CreateTargetResult ¶
type CreateTargetResult struct {
// The ID of the page opened.
ID ID `json:"targetId"`
// Error information related to executing this method
Err error `json:"-"`
}
CreateTargetResult represents the result of calls to Target.createTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-createTarget
type CreatedEvent ¶
type CreatedEvent struct {
// Target info.
Info *Info `json:"targetInfo"`
// Error information related to this event
Err error `json:"-"`
}
CreatedEvent represents Target.targetCreated event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-targetCreated
type DestroyedEvent ¶
type DestroyedEvent struct {
// Target ID.
ID ID `json:"targetId"`
// Error information related to this event
Err error `json:"-"`
}
DestroyedEvent represents Target.targetDestroyed event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-targetDestroyed
type DetachFromTargetParams ¶
type DetachFromTargetParams struct {
// Optional. Session to detach.
SessionID SessionID `json:"sessionId,omitempty"`
// Optional. DEPRECATED
ID ID `json:"targetId,omitempty"`
}
DetachFromTargetParams represents Target.detachFromTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-detachFromTarget
type DetachFromTargetResult ¶
type DetachFromTargetResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
DetachFromTargetResult represents the result of calls to Target.detachFromTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-detachFromTarget
type DetachedFromTargetEvent ¶
type DetachedFromTargetEvent struct {
// Detached session identifier.
SessionID SessionID `json:"sessionId"`
// DEPRECATED
ID ID `json:"targetId"`
// Error information related to this event
Err error `json:"-"`
}
DetachedFromTargetEvent represents Target.detachedFromTarget event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-detachedFromTarget
type DisposeBrowserContextParams ¶
type DisposeBrowserContextParams struct {
// Target ID.
ID ID `json:"targetId"`
}
DisposeBrowserContextParams represents Target.disposeBrowserContext parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-disposeBrowserContext
type DisposeBrowserContextResult ¶
type DisposeBrowserContextResult struct {
Success bool `json:"success"`
// Error information related to executing this method
Err error `json:"-"`
}
DisposeBrowserContextResult represents the result of calls to Target.disposeBrowserContext.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-disposeBrowserContext
type GetTargetInfoParams ¶
type GetTargetInfoParams struct {
// Target ID.
ID ID `json:"targetId"`
}
GetTargetInfoParams represents Target.getTargetInfo parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-getTargetInfo
type GetTargetInfoResult ¶
type GetTargetInfoResult struct {
// The list of targets.
Infos []*Info `json:"targetInfos"`
// Error information related to executing this method
Err error `json:"-"`
}
GetTargetInfoResult represents the result of calls to Target.getTargetInfo.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-getTargetInfo
type GetTargetsParams ¶
type GetTargetsParams struct {
// The list of targets.
Infos []*Info `json:"targetInfos"`
}
GetTargetsParams represents Target.getTargets parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-getTargets
type GetTargetsResult ¶
type GetTargetsResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
GetTargetsResult represents the result of calls to Target.getTargets.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-getTargets
type ID ¶
type ID string
ID is the target ID.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetID
type Info ¶
type Info struct {
// desc.
ID ID `json:"targetId"`
// desc.
Type string `json:"type"`
// desc.
Title string `json:"title"`
// desc.
URL string `json:"url"`
// Whether the target has an attached client.
Attached bool `json:"attached"`
// Optional. Opener target Id.
OpenerID ID `json:"openerId,omitempty"`
}
Info holds the target info.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-TargetInfo
type InfoChangedEvent ¶
type InfoChangedEvent struct {
// Target info.
Info *Info `json:"targetInfo"`
// Error information related to this event
Err error `json:"-"`
}
InfoChangedEvent represents Target.targetInfoChanged event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-targetInfoChanged
type ReceivedMessageFromTargetEvent ¶
type ReceivedMessageFromTargetEvent struct {
// Identifier of a session which sends a message.
SessionID SessionID `json:"sessionId"`
// Message.
Message string `json:"message"`
// Optional. Deprecated. DEPRECATED.
ID ID `json:"targetId,omitempty"`
// Error information related to this event
Err error `json:"-"`
}
ReceivedMessageFromTargetEvent represents Target.receivedMessageFromTarget event data.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#event-receivedMessageFromTarget
type RemoteLocation ¶
RemoteLocation is EXPERIMENTAL
https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-RemoteLocation
type SendMessageToTargetParams ¶
type SendMessageToTargetParams struct {
// Message.
Message string `json:"message"`
// Optional. Identifier of the session.
SessionID SessionID `json:"sessionId,omitempty"`
// Optional. DEPRECATED
ID ID `json:"targetId,omitempty"`
}
SendMessageToTargetParams represents Target.sendMessageToTarget parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-sendMessageToTarget
type SendMessageToTargetResult ¶
type SendMessageToTargetResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
SendMessageToTargetResult represents the result of calls to Target.sendMessageToTarget.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-sendMessageToTarget
type SessionID ¶
type SessionID string
SessionID is a unique identifier of attached debugging session.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#type-SessionID
type SetAttachToFramesParams ¶
type SetAttachToFramesParams struct {
// Whether to attach to frames.
Value bool `json:"value"`
}
SetAttachToFramesParams represents Target.setAttachToFrames parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setAttachToFrames
type SetAttachToFramesResult ¶
type SetAttachToFramesResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
SetAttachToFramesResult represents the result of calls to Target.setAttachToFrames.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setAttachToFrames
type SetAutoAttachParams ¶
type SetAutoAttachParams struct {
// Whether to auto-attach to related targets.
AutoAttach bool `json:"autoAttach"`
// Whether to pause new targets when attaching to them. Use
// `Runtime.runIfWaitingForDebugger` to run paused targets.
WaitForDebuggerOnStart bool `json:"waitForDebuggerOnStart"`
}
SetAutoAttachParams represents Target.setAutoAttach parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setAutoAttach
type SetAutoAttachResult ¶
type SetAutoAttachResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
SetAutoAttachResult represents the result of calls to Target.setAutoAttach.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setAutoAttach
type SetDiscoverTargetsParams ¶
type SetDiscoverTargetsParams struct {
// Whether to discover available targets.
Discover bool `json:"discover"`
}
SetDiscoverTargetsParams represents Target.setDiscoverTargets parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setDiscoverTargets
type SetDiscoverTargetsResult ¶
type SetDiscoverTargetsResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
SetDiscoverTargetsResult represents the result of calls to Target.setDiscoverTargets.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setDiscoverTargets
type SetRemoteLocationsParams ¶
type SetRemoteLocationsParams struct {
// List of remote locations.
Locations []*RemoteLocation `json:"locations"`
}
SetRemoteLocationsParams represents Target.setRemoteLocations parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setRemoteLocations
type SetRemoteLocationsResult ¶
type SetRemoteLocationsResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
SetRemoteLocationsResult represents the result of calls to Target.setRemoteLocations.
https://chromedevtools.github.io/devtools-protocol/tot/Target/#method-setRemoteLocations