Documentation
¶
Overview ¶
Package tracing provides type definitions for use with the Chrome Tracing protocol
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/
Index ¶
- Variables
- type BufferUsageEvent
- type CompleteEvent
- type DataCollectedEvent
- type EndResult
- type GetCategoriesResult
- type MemoryDumpConfig
- type RecordClockSyncMarkerParams
- type RecordClockSyncMarkerResult
- type RecordModeEnum
- type RequestMemoryDumpResult
- type StartParams
- type StartResult
- type StreamCompressionEnum
- type TraceConfig
- type TransferModeEnum
Constants ¶
This section is empty.
Variables ¶
var RecordMode = recordModeEnum{
RecordUntilFull: recordModeRecordUntilFull,
RecordContinuously: recordModeRecordContinuously,
RecordAsMuchAsPossible: recordModeRecordAsMuchAsPossible,
EchoToConsole: recordModeEchoToConsole,
}
RecordMode provides named acces to the RecordModeEnum values.
var StreamCompression = streamCompressionEnum{
None: streamCompressionNone,
Gzip: streamCompressionGzip,
}
StreamCompression provides named acces to the StreamCompressionEnum values.
var TransferMode = transferModeEnum{
ReportEvents: transferModeReportEvents,
ReturnAsStream: transferModeReturnAsStream,
}
TransferMode provides named acces to the TransferModeEnum values.
Functions ¶
This section is empty.
Types ¶
type BufferUsageEvent ¶
type BufferUsageEvent struct {
// Optional. A number in range [0..1] that indicates the used size of event
// buffer as a fraction of its total size.
PercentFull float64 `json:"percentFull,omitempty"`
// Optional. An approximate number of events in the trace log.
EventCount int64 `json:"eventCount,omitempty"`
// Optional. A number in range [0..1] that indicates the used size of event
// buffer as a fraction of its total size.
Value float64 `json:"value,omitempty"`
// Error information related to this event
Err error `json:"-"`
}
BufferUsageEvent represents Overlay.bufferUsage event data.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-bufferUsage
type CompleteEvent ¶
type CompleteEvent struct {
// Optional. A handle of the stream that holds resulting trace data.
Stream io.StreamHandle `json:"stream,omitempty"`
// Error information related to this event
Err error `json:"-"`
}
CompleteEvent represents Overlay.tracingComplete event data.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-tracingComplete
type DataCollectedEvent ¶
type DataCollectedEvent struct {
Value []map[string]string `json:"value"`
// Error information related to this event
Err error `json:"-"`
}
DataCollectedEvent represents Overlay.dataCollected event data.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-dataCollected
type EndResult ¶
type EndResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
EndResult represents the result of calls to Tracing.end.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-end
type GetCategoriesResult ¶
type GetCategoriesResult struct {
// A list of supported tracing categories.
Categories []string `json:"categories"`
// Error information related to executing this method
Err error `json:"-"`
}
GetCategoriesResult represents the result of calls to Tracing.getCategories.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-getCategories
type MemoryDumpConfig ¶
MemoryDumpConfig is the configuration for memory dump. Used only when "memory-infra" category is enabled.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#type-MemoryDumpConfig
type RecordClockSyncMarkerParams ¶
type RecordClockSyncMarkerParams struct {
// The ID of this clock sync marker
SyncID string `json:"syncId"`
}
RecordClockSyncMarkerParams represents Tracing.recordClockSyncMarker parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-recordClockSyncMarker
type RecordClockSyncMarkerResult ¶
type RecordClockSyncMarkerResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
RecordClockSyncMarkerResult represents the result of calls to Tracing.recordClockSyncMarker.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-recordClockSyncMarker
type RecordModeEnum ¶
type RecordModeEnum int
RecordModeEnum is optional. Controls how the trace buffer stores data. Allowed values:
- RecordMode.RecordUntilFull "recordUntilFull"
- RecordMode.RecordContinuously "recordContinuously"
- RecordMode.RecordAsMuchAsPossible "recordAsMuchAsPossible"
- RecordMode.EchoToConsole "echoToConsole"
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#type-TraceConfig
func (RecordModeEnum) MarshalJSON ¶
func (enum RecordModeEnum) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (RecordModeEnum) String ¶
func (enum RecordModeEnum) String() string
String implements Stringer
func (*RecordModeEnum) UnmarshalJSON ¶
func (enum *RecordModeEnum) UnmarshalJSON(bytes []byte) error
UnmarshalJSON implements json.Unmarshaler
type RequestMemoryDumpResult ¶
type RequestMemoryDumpResult struct {
// GUID of the resulting global memory dump.
DumpGUID string `json:"dumpGuid"`
// True if the global memory dump succeeded.
Success bool `json:"success"`
// Error information related to executing this method
Err error `json:"-"`
}
RequestMemoryDumpResult represents the result of calls to Tracing.requestMemoryDump.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-requestMemoryDump
type StartParams ¶
type StartParams struct {
// Optional. Category/tag filter.
Categories string `json:"categories,omitempty"`
// Optional. Tracing options.
Options string `json:"options,omitempty"`
// Optional. If set, the agent will issue bufferUsage events at this
// interval, specified in milliseconds.
BufferUsageReportingInterval int64 `json:"bufferUsageReportingInterval,omitempty"`
// Optional. Whether to report trace events as series of dataCollected
// events or to save trace to a stream (defaults to `ReportEvents`). Allowed
// values:
// - ReportEvents
// - ReturnAsStream
TransferMode TransferModeEnum `json:"transferMode,omitempty"`
// Optional. Trace config.
TraceConfig *TraceConfig `json:"traceConfig,omitempty"`
}
StartParams represents Tracing.start parameters.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-start
type StartResult ¶
type StartResult struct {
// Error information related to executing this method
Err error `json:"-"`
}
StartResult represents the result of calls to Tracing.start.
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#method-start
type StreamCompressionEnum ¶
type StreamCompressionEnum int
StreamCompressionEnum represents the compression type to use for traces returned via streams. Allowed values:
- StreamCompression.None "none"
- StreamCompression.Gzip "gzip"
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#type-StreamCompression
func (StreamCompressionEnum) MarshalJSON ¶
func (enum StreamCompressionEnum) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (StreamCompressionEnum) String ¶
func (enum StreamCompressionEnum) String() string
String implements Stringer
func (*StreamCompressionEnum) UnmarshalJSON ¶
func (enum *StreamCompressionEnum) UnmarshalJSON(bytes []byte) error
UnmarshalJSON implements json.Unmarshaler
type TraceConfig ¶
type TraceConfig struct {
// Optional. Controls how the trace buffer stores data. Allowed values:
// - RecordMode.RecordUntilFull
// - RecordMode.RecordContinuously
// - RecordMode.RecordAsMuchAsPossible
// - RecordMode.EchoToConsole
RecordMode RecordModeEnum `json:"recordMode,omitempty"`
// Optional. Turns on JavaScript stack sampling.
EnableSampling bool `json:"enableSampling,omitempty"`
// Optional. Turns on system tracing.
EnableSystrace bool `json:"enableSystrace,omitempty"`
// Optional. Turns on argument filter.
EnableArgumentFilter bool `json:"enableArgumentFilter,omitempty"`
// Optional. Included category filters.
IncludedCategories []string `json:"includedCategories,omitempty"`
// Optional. Excluded category filters.
ExcludedCategories []string `json:"excludedCategories,omitempty"`
// Optional. Configuration to synthesize the delays in tracing.
SyntheticDelays []string `json:"syntheticDelays,omitempty"`
// Optional. Configuration for memory dump triggers. Used only when
// "memory-infra" category is enabled.
MemoryDumpConfig MemoryDumpConfig `json:"memoryDumpConfig,omitempty"`
}
TraceConfig is the trace configuration
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#type-TraceConfig
type TransferModeEnum ¶
type TransferModeEnum int
TransferModeEnum is optional. Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to `ReportEvents`). Allowed values:
- TransferMode.ReportEvents "ReportEvents"
- TransferMode.ReturnAsStream "ReturnAsStream"
https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#type-TraceConfig
func (TransferModeEnum) MarshalJSON ¶
func (enum TransferModeEnum) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (TransferModeEnum) String ¶
func (enum TransferModeEnum) String() string
String implements Stringer
func (*TransferModeEnum) UnmarshalJSON ¶
func (enum *TransferModeEnum) UnmarshalJSON(bytes []byte) error
UnmarshalJSON implements json.Unmarshaler